This is the documentation for my module. Pypwing is a graphical password component. Here are some of its methods.

Pypwingw()
创建实例 Create an instance.

text.addwindow(x,y,size) 
新建窗口并设定大小和位置 Create a new window and set its size and position.

text.inputpassword("password") 
设置密码 Create new password.

inputturecommand(self,command)
设置密码正确时执行的模块 Function to execute when setting password correctly.

inputerrorcommand(self,command)
设置密码错误时执行的模块 Function executed when setting password error.

geterrornumber(self)
打印错误次数 Print number of errors.

exit(self)
#退出窗口 Exit window.

At last,I want to say this methods is only made with a eleven years old boy in chinese,so some function's name look not good and this documentation look not good,too.But I think is easily to use it.


